function postprocessMEDIALAB(simValues)
close all;
[depth, time, speciesName, inputFile, r, R, reactionUnits] = userMEDIALAB;
[speciesPhase, stochiometrix, advection, diffusion, reaction, plBC, prBC ] = autoMEDIALAB(speciesName,inputFile, r, R, reactionUnits);
load('resultMEDIALAB.mat')
for iT=1:length(time)
    for iX=1:length(depth)
        for i=1:length(simValues)
            u(i)=simValues{i}(iT,iX);
        end
        for i=1:length(r)
            ratesValues{i}(iT,iX)= reaction{i}(u);                         % time and space-dependent calculation of reaction rates
        end
    end
end

for i=1:length(r)
    for j=1:length(time)
        rateValuesTemporal(i,j) = trapz(depth,ratesValues{i}(j,:));        % reaction rates are integrated with respect to depth to obtain temporal rate values
    end
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
%*****************PLOTTING PROFILE FIGURES OF DISSOLVED SPECIES***********%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
figure;
subplot(2,4,1);
plotMEDIALAB(speciesName,simValues,depth, 'fieldData.xlsx', 'o2(aq)', {'o2(aq)'});
hold on;

subplot(2,4,2);
plotMEDIALAB(speciesName,simValues,depth, 'fieldData.xlsx', 'no3(aq)', {'no3(aq)'});
hold on;

subplot(2,4,3);
plotMEDIALAB(speciesName,simValues,depth, 'fieldData.xlsx', 'so4(aq)', {'so4(aq)'});
hold on;

subplot(2,4,4);
plotMEDIALAB(speciesName,simValues,depth, 'fieldData.xlsx', 'ch4(aq)', {'ch4(aq)'});
hold on;

subplot(2,4,5);
plotMEDIALAB(speciesName,simValues,depth, 'fieldData.xlsx', 'nh4(aq)', {'nh4(aq)'});
hold on;

subplot(2,4,6);
plotMEDIALAB(speciesName,simValues,depth, 'fieldData.xlsx', 'mn(aq)', {'mn(aq)'});
hold on;

subplot(2,4,7);
plotMEDIALAB(speciesName,simValues,depth, 'fieldData.xlsx', 'fe(aq)', {'fe(aq)'});
hold on;

subplot(2,4,8);
plotMEDIALAB(speciesName,simValues,depth, 'fieldData.xlsx', 'hpo4(aq)', {'hpo4(aq)'});

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
%************************PLOTTING OM POOLS AND TOC PROFILES***************%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
figure;
subplot(1,4,1);
plotMEDIALAB(speciesName,simValues,depth, 'fieldData.xlsx', 'TOC(s)', {'om1(s)'});
subplot(1,4,2);
plotMEDIALAB(speciesName,simValues,depth, 'fieldData.xlsx', 'TOC(s)', {'om2(s)'});
subplot(1,4,3);
plotMEDIALAB(speciesName,simValues,depth, 'fieldData.xlsx', 'TOC(s)', {'om3(s)'});
subplot(1,4,4);
plotMEDIALAB(speciesName,simValues,depth, 'fieldData.xlsx', 'TOC(s)', {'om1(s)','om2(s)','om3(s)'});

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
%*****************PLOTTING MnO2 POOLS AND TOTAL Mn(s) PROFILES************%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
figure;
subplot(1,3,1);
plotMEDIALAB(speciesName,simValues,depth, 'fieldData.xlsx', 'TMn(s)', {'mo_1(s)'});
subplot(1,3,2);
plotMEDIALAB(speciesName,simValues,depth, 'fieldData.xlsx', 'TMn(s)', {'mo_2(s)'});
subplot(1,3,3);
plotMEDIALAB(speciesName,simValues,depth, 'fieldData.xlsx', 'TMn(s)', {'mo_2(s)','mo_1(s)'});

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
%**************PLOTTING Fe(OH)3 POOLS AND TOTAL Fe(s) PROFILES************%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
figure;
subplot(2,3,1);
plotMEDIALAB(speciesName,simValues,depth, 'fieldData.xlsx', 'TFe(s)', {'foh(s)'});
subplot(2,3,2);
plotMEDIALAB(speciesName,simValues,depth, 'fieldData.xlsx', 'TFe(s)', {'fs(s)'});
subplot(2,3,3);
plotMEDIALAB(speciesName,simValues,depth, 'fieldData.xlsx', 'TFe(s)', {'pyrite(s)'});
subplot(2,3,4);
plotMEDIALAB(speciesName,simValues,depth, 'fieldData.xlsx', 'TFe(s)', {'vivianite(s)'});
subplot(2,3,5);
plotMEDIALAB(speciesName,simValues,depth, 'fieldData.xlsx', 'TFe(s)', {'vivianite(s)','foh(s)','fs(s)','pyrite(s)'});

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
%***********************PLOTTING TOTAL P(s) PRFILE************************%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
figure;
subplot(2,3,1);
plotMEDIALAB(speciesName,simValues,depth, 'fieldData.xlsx', 'TFe(s)', {'foh(s)'});
subplot(2,3,2);
plotMEDIALAB(speciesName,simValues,depth, 'fieldData.xlsx', 'TFe(s)', {'fs(s)'});
subplot(2,3,3);
plotMEDIALAB(speciesName,simValues,depth, 'fieldData.xlsx', 'TFe(s)', {'pyrite(s)'});
subplot(2,3,4);
plotMEDIALAB(speciesName,simValues,depth, 'fieldData.xlsx', 'TFe(s)', {'vivianite(s)'});
subplot(2,3,5);
plotMEDIALAB(speciesName,simValues,depth, 'fieldData.xlsx', 'TFe(s)', {'vivianite(s)','foh(s)','fs(s)','pyrite(s)'});

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
%*****************PLOTTING REACTION RATES PROFILES************************%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
figure;
for i=1:16
    subplot(4,4,i)
    y = ratesValues{i}(end,:);
    plot(y,depth);
    %title(rateTitles{i}, 'FontSize',16,'FontWeight','bold');
    hold on;
    set(gca,'YDir','reverse');                                             %reverse the y-axis, since depth should increase from top to bottom
    set(gcf,'Position',get(0,'ScreenSize'));                               %maximize the figure
    set(gcf,'PaperPosition',[3,5,24,11]);                                  %set the dimensions on paper when the plots are printed
    set(gca,'FontSize',8);                                                 %set the font size
    xmax=max(ratesValues{i}(end,:));
    if(xmax==0)xmax=xmax+0.5;end
    xlim([0 xmax]);
end

figure;
for i=17:31
    subplot(4,4,i-16)
    y = ratesValues{i}(end,:);
    plot(y,depth);
    %title(rateTitles{i}, 'FontSize',16,'FontWeight','bold');
    hold on;
    set(gca,'YDir','reverse');              
    set(gcf,'Position',get(0,'ScreenSize'));
    set(gcf,'PaperPosition',[3,5,24,11]);  
    set(gca,'FontSize',8);                  
    xmax=max(ratesValues{i}(end,:));
    if(xmax==0)xmax=xmax+0.5;end
    xlim([0 xmax]);
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
%*****************PLOTTING TEMPORAL SOLID IRON FRACTION ******************%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
subplot(2,2,1);
FeOH3   = simValues{4}(10,:);
Fe      = simValues{8}(10,:);
FeS     = simValues{10}(10,:);
FeS2    = simValues{11}(10,:);
Viv     = simValues{18}(10,:);
Fetot   = FeOH3+FeS+FeS2+Viv*3;
Y1      = (FeS./Fetot)';
Y2      = (FeS2./Fetot)';
Y3      = (3*Viv./Fetot)';
Y4      = (FeOH3./Fetot)';
Y=[Y1,Y2,Y3,Y4];
X=[depth',depth',depth',depth'];
Y(1,1)=0;
area(depth',Y);
ylim([0 1]);
legend('FeS','FeS_2','Fe_3(PO_4)_2','Fe(OH)_3');
xlabel('depth(cm)','FontSize',16);
title('% Fe (after 10 yrs)','FontSize',16,'FontWeight','bold');

subplot(2,2,2);
FeOH3   = simValues{4}(33,:);
Fe      = simValues{8}(33,:);
FeS     = simValues{10}(33,:);
FeS2    = simValues{11}(33,:);
Viv     = simValues{18}(33,:);
Fetot   = FeOH3+FeS+FeS2+Viv*3;
Y1      = (FeS./Fetot)';
Y2      = (FeS2./Fetot)';
Y3      = (3*Viv./Fetot)';
Y4      = (FeOH3./Fetot)';
Y=[Y1,Y2,Y3,Y4];
X=[depth',depth',depth',depth'];
Y(1,1)=0;
area(depth',Y);
ylim([0 1]);
legend('FeS','FeS_2','Fe_3(PO_4)_2','Fe(OH)_3');
xlabel('depth(cm)','FontSize',16);
title('% Fe (after 33 yrs)','FontSize',16,'FontWeight','bold');        

subplot(2,2,3);
FeOH3   = simValues{4}(53,:);
Fe      = simValues{8}(53,:);
FeS     = simValues{10}(53,:);
FeS2    = simValues{11}(53,:);
Viv     = simValues{18}(53,:);
Fetot   = FeOH3+FeS+FeS2+Viv*3;
Y1      = (FeS./Fetot)';
Y2      = (FeS2./Fetot)';
Y3      = (3*Viv./Fetot)';
Y4      = (FeOH3./Fetot)';
Y=[Y1,Y2,Y3,Y4];
X=[depth',depth',depth',depth'];
Y(1,1)=0;
area(depth',Y);
ylim([0 1]);
legend('FeS','FeS_2','Fe_3(PO_4)_2','Fe(OH)_3');
xlabel('depth(cm)','FontSize',16);
title('% Fe (after 55 yrs)','FontSize',16,'FontWeight','bold');
        
subplot(2,2,4);
FeOH3   = simValues{4}(end,:);
Fe      = simValues{8}(end,:);
FeS     = simValues{10}(end,:);
FeS2    = simValues{11}(end,:);
Viv     = simValues{18}(end,:);
Fetot   = FeOH3+FeS+FeS2+Viv*3;
Y1      = (FeS./Fetot)';
Y2      = (FeS2./Fetot)';
Y3      = (3*Viv./Fetot)';
Y4      = (FeOH3./Fetot)';
Y=[Y1,Y2,Y3,Y4];
X=[depth',depth',depth',depth'];
Y(1,1)=0;
area(depth',Y);
ylim([0 1]);
legend('FeS','FeS_2','Fe_3(PO_4)_2','Fe(OH)_3');
xlabel('depth(cm)','FontSize',16);
title('% Fe (at steady state)','FontSize',16,'FontWeight','bold');  

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
%**************PLOTTING TEMPORAL OM MINRELIZATION PATHWAYS ***************%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
figure;
r_OM_O2  = rateValuesTemporal(1,:)+rateValuesTemporal(2,:);
r_OM_NO3 = rateValuesTemporal(3,:)+rateValuesTemporal(4,:);
r_OM_MnO = rateValuesTemporal(5,:)+rateValuesTemporal(6,:);
r_OM_FeO = rateValuesTemporal(7,:)+rateValuesTemporal(8,:);
r_OM_SO  = rateValuesTemporal(9,:)+rateValuesTemporal(10,:);
r_OM_CH  = rateValuesTemporal(11,:)+rateValuesTemporal(12,:);
degOM    = r_OM_O2 + r_OM_NO3 + r_OM_MnO + r_OM_FeO + r_OM_SO + r_OM_CH;
Y1       =(r_OM_O2./degOM)';
Y2       =(r_OM_NO3./degOM)';
Y3       =(r_OM_MnO./degOM)';
Y4       =(r_OM_FeO./degOM)';
Y5       =(r_OM_SO./degOM)';
Y6       =(r_OM_CH./degOM)';
Y1(1)    = 0;
Y2(1)    = 0;
Y3(1)    = 0;
Y4(1)    = 0;
Y5(1)    = 0;
Y6(1)    = 0;
Y        = [Y1,Y2,Y3,Y4,Y5,Y6];
X        = [time',time',time',time',time',time'];
area(time',Y);
ylim([0 1]);
xlabel('time(yr)','FontSize',16);
title('% Om degredation pathways','FontSize',16,'FontWeight','bold');
%legend(rateTitles{1:2:11});